@@ -9,3 +9,7 @@ here = File.expand_path(File.dirname(__FILE__))
 $: << File.expand_path("#{here}/../lib")
 
 require "rerun"
+
+RSpec.configure do |config|
+  config.expect_with(:rspec) { |c| c.syntax = %i[expect should] }
+end
